@@ -68,7 +68,7 @@ wnck_class_group_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckClassGroupClass),
         (GBaseInitFunc) NULL,
@@ -509,6 +509,9 @@ _wnck_class_group_remove_window (WnckClassGroup *class_group,
 
   priv->windows = g_list_remove (priv->windows, window);
   _wnck_window_set_class_group (window, NULL);
+
+  set_name (class_group);
+  set_icon (class_group);
 }
 
 /**
