@@ -178,7 +178,7 @@ wnck_screen_get_type (void)
   
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckScreenClass),
         (GBaseInitFunc) NULL,
