@@ -8,7 +8,6 @@ create_pager_window (WnckScreen *screen,
 {
   GtkWidget *win;
   GtkWidget *pager;
-  GtkWidget *frame;
   
   win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -27,16 +26,13 @@ create_pager_window (WnckScreen *screen,
                     G_CALLBACK (gtk_main_quit),
                     NULL);
 
-  frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-  gtk_container_add (GTK_CONTAINER (win), frame);
-  
   pager = wnck_pager_new (screen);
 
   wnck_pager_set_orientation (WNCK_PAGER (pager), orientation);
   wnck_pager_set_n_rows (WNCK_PAGER (pager), 3);
+  wnck_pager_set_shadow_type (WNCK_PAGER (pager), GTK_SHADOW_IN);
   
-  gtk_container_add (GTK_CONTAINER (frame), pager);  
+  gtk_container_add (GTK_CONTAINER (win), pager);
   
   gtk_widget_show_all (win);
 }
@@ -48,7 +44,11 @@ main (int argc, char **argv)
   
   gtk_init (&argc, &argv);
 
-  screen = wnck_screen_get (0);
+  /* to test rtl layout, set RTL=1 in the environment */
+  if (g_getenv ("RTL"))
+    gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
+
+  screen = wnck_screen_get_default ();
 
   /* because the pager doesn't respond to signals at the moment */
   wnck_screen_force_update (screen);
